package com.miaxis.app.controller.question;

import com.miaxis.common.constant.Constants;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.question.domain.QuestionInfo;
import com.miaxis.question.dto.QuestionInfoDTO;
import com.miaxis.question.dto.QuestionInfoTestDTO;
import com.miaxis.question.service.IQuestionInfoService;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 【题库】Controller
 *
 * @author miaxis
 * @date 2021-10-20
 */
@RestController
@RequestMapping(Constants.OPEN_PREFIX+"/question/info")
@Api(tags={"【H5-题库】"})
public class QuestionInfoController extends BaseController {
    @Autowired
    private IQuestionInfoService questionInfoService;

    /**
     * 查询题库列表
     */
    @GetMapping("/list")
    @ApiOperation("查询题库列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<QuestionInfo> list(@ModelAttribute QuestionInfoDTO questionInfoDTO){
        startPage();
        List<QuestionInfo> list = questionInfoService.selectQuestionInfoList(questionInfoDTO);
        return toResponsePageInfo(list);
    }

    /**
     * 获取题库详细信息
     */
    @GetMapping(value = "/{id}")
    @ApiOperation("获取题库详细信息")
    public Response<QuestionInfo> getInfo(
            @ApiParam(name = "id", value = "题库参数", required = true)
            @PathVariable("id") Long id
    ){
        return Response.success(questionInfoService.getById(id));
    }



    /**
     * 根据ydtid获取题目
     */
    @GetMapping(value = "/getQuestionInfoByYdtIds")
    @ApiOperation("根据ydtid获取题目")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "ids",value = "题目ids" ,dataType = "List", required = true)
    })
    public ResponsePageInfo<QuestionInfo> getQuestionInfoByYdtIds(Long[] ids){
        List<QuestionInfo> list = questionInfoService.selectQuestionInfoListByYdtIds(ids);
        return toResponsePageInfo(list);
    }



    /**
     * 根据id获取题目
     */
    @GetMapping(value = "/getQuestionInfoByIds")
    @ApiOperation("根据id获取题目")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "ids",value = "题目ids" ,dataType = "List", required = true)
    })
    public ResponsePageInfo<QuestionInfo> getQuestionInfoByIds(Long[] ids){
        List<QuestionInfo> list = questionInfoService.selectQuestionInfoListByIds(ids);
        return toResponsePageInfo(list);
    }


    /**
     * 查询模拟考试科目1与4题库
     */
    @GetMapping("/selectTestK14QuestionInfoList")
    @ApiOperation("取模拟考试题库")
    public ResponsePageInfo<QuestionInfo> selectTestK14QuestionInfoList(@ModelAttribute QuestionInfoTestDTO questionInfoTestDTO){
        List<QuestionInfo> list = questionInfoService.selectTestK14QuestionInfoList(questionInfoTestDTO);
        return toResponsePageInfo(list);
    }

}

