package com.miaxis.app.controller.question;

import com.miaxis.common.annotation.Log;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.common.enums.BusinessTypeEnum;
import com.miaxis.common.utils.poi.ExcelUtil;
import com.miaxis.question.domain.QuestionInfoKtGet;
import com.miaxis.question.service.IQuestionInfoKtGetService;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.List;

/**
 * 【获取快通题库】Controller
 *
 * @author miaxis
 * @date 2022-04-08
 */
@RestController
@RequestMapping("/kt/get")
@Api(tags={"【小程序-获取快通题库】"})
public class QuestionInfoKtGetController extends BaseController{
    @Autowired
    private IQuestionInfoKtGetService questionInfoKtGetService;

    /**
     * 查询获取快通题库列表
     */
    @PreAuthorize("@ss.hasPermi('kt:get:list')")
    @GetMapping("/list")
    @ApiOperation("查询获取快通题库列表")
        @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<QuestionInfoKtGet> list(@ModelAttribute QuestionInfoKtGet questionInfoKtGet){
        startPage();
        List<QuestionInfoKtGet> list = questionInfoKtGetService.selectQuestionInfoKtGetList(questionInfoKtGet);
        return toResponsePageInfo(list);
    }
    
    /**
     * 导出获取快通题库列表
     */
    @PreAuthorize("@ss.hasPermi('kt:get:export')")
    @Log(title = "获取快通题库", businessType = BusinessTypeEnum.EXPORT)
    @GetMapping("/export")
    @ApiOperation("导出获取快通题库列表Excel")
    public Response<String> export(@ModelAttribute QuestionInfoKtGet questionInfoKtGet){
        List<QuestionInfoKtGet> list = questionInfoKtGetService.selectQuestionInfoKtGetList(questionInfoKtGet);
        ExcelUtil<QuestionInfoKtGet> util = new ExcelUtil<QuestionInfoKtGet>(QuestionInfoKtGet.class);
        return util.exportExcel(list, "get");
    }

    /**
     * 获取获取快通题库详细信息
     */
    @PreAuthorize("@ss.hasPermi('kt:get:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取获取快通题库详细信息")
    public Response<QuestionInfoKtGet> getInfo(
            @ApiParam(name = "id", value = "获取快通题库参数", required = true)
            @PathVariable("id") Long id
    ){
        return Response.success(questionInfoKtGetService.getById(id));
    }

    /**
     * 新增获取快通题库
     */
    @PreAuthorize("@ss.hasPermi('kt:get:add')")
    @Log(title = "获取快通题库", businessType = BusinessTypeEnum.INSERT)
    @PostMapping
    @ApiOperation("新增获取快通题库")
    public Response<Integer> add(@RequestBody QuestionInfoKtGet questionInfoKtGet){
        return toResponse(questionInfoKtGetService.save(questionInfoKtGet) ? 1 : 0);
    }

    /**
     * 修改获取快通题库
     */
    @PreAuthorize("@ss.hasPermi('kt:get:edit')")
    @Log(title = "获取快通题库", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping
    @ApiOperation("修改获取快通题库")
    public Response<Integer> edit(@RequestBody QuestionInfoKtGet questionInfoKtGet){
        return toResponse(questionInfoKtGetService.updateById(questionInfoKtGet) ? 1 : 0);
    }

    /**
     * 删除获取快通题库
     */
    @PreAuthorize("@ss.hasPermi('kt:get:remove')")
    @Log(title = "获取快通题库", businessType = BusinessTypeEnum.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除获取快通题库")
    public  Response<Integer> remove(
            @ApiParam(name = "ids", value = "获取快通题库ids参数", required = true)
            @PathVariable Long[] ids
    ){
        return toResponse(questionInfoKtGetService.removeByIds(Arrays.asList(ids)) ? 1 : 0);
    }
}
