package com.miaxis.app.controller.teachingDsp;

import com.miaxis.common.constant.Constants;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.teachingDsp.domain.TeachingDspInfo;
import com.miaxis.teachingDsp.service.ITeachingDspInfoService;
import com.miaxis.teachingDsp.vo.TeachingDspInfoVo;
import io.swagger.annotations.*;
import lombok.AllArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 【学车短视频】Controller
 *
 * @author miaxis
 * @date 2021-12-09
 */
@RestController
@AllArgsConstructor
@RequestMapping(Constants.OPEN_PREFIX+"/teachingDsp/dsp")
@Api(tags={"【小程序-学车短视频】"})
public class AppTeachingDspInfoController extends BaseController{
    @Autowired
    private ITeachingDspInfoService teachingDspInfoService;

    /**
     * 查询学车短视频列表
     */
    @GetMapping("/list")
    @ApiOperation("查询学车短视频列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<TeachingDspInfoVo> list(@ModelAttribute TeachingDspInfo teachingDspInfo){
        startPage();
        List<TeachingDspInfoVo> list = teachingDspInfoService.selectTeachingDspInfoList(teachingDspInfo);
        return toResponsePageInfo(list);
    }


    /**
     * 获取学车短视频详细信息
     */
    @GetMapping(value = "/{id}")
    @ApiOperation("获取学车短视频详细信息")
    public Response<TeachingDspInfoVo> getInfo(
            @ApiParam(name = "id", value = "学车短视频参数", required = true)
            @PathVariable("id") Long id
    ){
        return teachingDspInfoService.getTeachingDspDetailsById(id);
    }


}
